@@ -10,8 +10,8 @@ from pathlib import Path
 from typing import Literal, Self, overload
 
 import orjson
-from furl import furl
 from typing_extensions import override
+from yarl import URL
 
 
 @total_ordering
@@ -132,7 +132,7 @@ class User:
     """
 
     name: str
-    profile: furl
+    profile: URL
 
     @override
     def __str__(self) -> str:
@@ -157,7 +157,7 @@ class Repository:
 
     owner: str
     name: str
-    url: furl
+    url: URL
 
     @override
     def __str__(self) -> str:
@@ -170,7 +170,7 @@ class Repository:
         return self.name.lower()
 
     @property
-    def issues(self) -> furl:
+    def issues(self) -> URL:
         """Return a URl pointing to the repository's issues page."""
         return self.url / "issues"
 
@@ -196,7 +196,7 @@ class CogMetadata:
     version: SemVer
     authors: list[User]
     repository: Repository
-    documentation: furl | None = None
+    documentation: URL | None = None
 
     @classmethod
     def from_json(cls, cog_name: str, file: Path) -> Self:
@@ -212,10 +212,10 @@ class CogMetadata:
         with open(file, "rb") as f:
             obj = orjson.loads(f.read())
 
-        authors = [User(name=author["name"], profile=furl(author["url"])) for author in obj["authors"]]
-        repository = Repository(owner=obj["repository"]["owner"], name=obj["repository"]["name"], url=furl(obj["repository"]["url"]))
+        authors = [User(name=author["name"], profile=URL(author["url"])) for author in obj["authors"]]
+        repository = Repository(owner=obj["repository"]["owner"], name=obj["repository"]["name"], url=URL(obj["repository"]["url"]))
         if (documentation := obj.get("documentation", None)) is not None:
-            documentation = furl(documentation)
+            documentation = URL(documentation)
         version = SemVer.from_str(obj["version"])
         return cls(name=cog_name, version=version, authors=authors, repository=repository, documentation=documentation)
 
