@@ -298,3 +298,8 @@ class CogModel(BaseModel):
     """
 
     cog: Cog = Field(exclude=True)
+
+    @property
+    def logger(self) -> RedTraceLogger:
+        """Get the cog's logger."""
+        return self.cog.logger
