@@ -968,7 +968,7 @@ class SentinelCog(Cog):
             PartialChannel: (channel_targets, None),
             PartialRole: (role_targets, None),
             abc.User: (user_targets, PartialUser.upsert),
-            GuildChannel: (channel_targets, PartialChannel.upsert),
+            GuildChannel: (channel_targets, PartialChannel.upsert),  # pyright: ignore[reportAssignmentType]
             Role: (role_targets, PartialRole.upsert),
         }
 
